@@ -160,6 +160,6 @@ listEdges <- function(object, dropNULL=TRUE)
 
 
 listLen <- function(list)
-    .Call("listLen", list, PACKAGE="graph")
+    .Call("listLen", list, PACKAGE="BioC_graph")
 
 
